==> tetzle_2.1.5+dfsg1.orig.tar.gz: tetzle-2.1.5+dfsg1/translations/tetzle_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Άνοιγμα Εικόνας</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Εμφάνιση</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Κορνίζα συνόρων</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Σκιές</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Χρώματα</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Φόντος:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Σκιά:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Επισήμανση:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Ελλειπής εικόνα.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Παρακαλώ περιμένετε</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Φόρτωση εικόνας...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Δημιουργία παζλ...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Δημιουργία κομματιών...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Φόρτωση παζλ...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Άγνωστη μορφή δεδομένων</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Άγνωστο στοιχείο &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Σφάλμα κατά την ανάλυση του XML αρχείου.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Φόρτωση κομματιών...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Ανάκτηση κομματιών...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Τοποθέτηση κομματιών...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Επιτυχία</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Επιλογή παιχνιδιού</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Τρέχοντα παιχνίδια</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Καινούργιο παιχνίδι</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Ιδιότητες Εικόνας</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Όνομα:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Κατηγορία:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Επιλογή γλώσσας εφαρμογής:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Σημείωση</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Παρακαλείστε να επανεκκινήσετε την εφαρμογή για να τεθεί σε ισχύ η αλλαγή της γλώσσας.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Προσθήκη Εικόνας</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Αφαίρεση Εικόνας</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Ιδιότητες Εικόνας</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 κομμάτια</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Αντιγραφή εικόνων...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>Αφαίρεση της επιλεγμένης εικόνας;</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Αφαίρεση της επιλεγμένης εικόνας;

Εκεί αποθηκεύονται τα παιχνίδια που χρησιμοποιούν αυτή την εικόνα που θα πρέπει επίσης να αφαιρεθεί.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Χωρίς τίτλο</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Χωρίς τίτλους</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 κομμάτια %2 %3% ολοκληρώθηκαν</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Διαγραφή παιχνιδιού</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Διαγραφή επιλεγμένου παιχνιδιού;</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Επισκόπηση</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Προσθήκη κατηγορίας</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Αφαίρεση Κατηγορίας</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Χωρίς κατηγορία</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Ολες οι εικόνες</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Χωρίς τίτλο %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Ερώτηση</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Αφαίρεση της επιλεγμένης κατηγορίας;</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Συγγνώμη</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Μια κατηγορία με αυτό το όνομα υπάρχει ήδη.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Παιχνίδι</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Ανάκτηση κομματιών</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+Ρ</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Τερματισμός</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Επιλογή...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Εμφάνιση</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Μεγέθυνση</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Μεγέθυνση</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>Καλύτερο ταίριασμα</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Εμφάνιση επ&amp;ισκόπησης</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Καρτέλα</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>Πλήρης οθόνη</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+Φ</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ρυθμίσεις</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Εμφάνιση...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Γλώσσα...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Βοήθεια</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Διαχείριση</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Σχετικά με</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Σχετικά με το &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Διαχείριση</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Κομμάτια πού λύθηκαν:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Πατήστε στην επιλογή αριστερά </translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Μειωμένα Κομμάτια:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Επιλεγμένα Κομμάτια:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Σύρετε Αριστερά</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Περιστροφή κομματιών:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Κάντε δεξί Κλικ για την ανάκτηση ελέγχου + αριστερό κλικ, η πατήστε το πλήκτρο Ρ</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Σύρετε το παζλ:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Κάντε μεσαίο Κλικ, Shift + Αριστερό Κλικ, η χρησιμοποιήστε τα βέλη</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Μεγέθυνση τού παζλ:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Κύλιση η +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Μετακίνηση Δρομέα:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Μετακινήστε το ποντίκι η πατήστε τα πλήκτρα Β,Α,Δ,Σ</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Σχετικά με το Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Παζλ με κομμάτια tetromino</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Πνευματικά δικαιώματα&amp;αντίγραφα; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Κυκλοφορία υπο την άδεια &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>;;%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation>Επιλογή έκδοσης OpenGL.</translation>
    </message>
    <message>
        <source>version</source>
        <translation>έκδοση</translation>
    </message>
</context>
</TS>

==> tetzle_2.2.2.orig.tar.gz: tetzle-2.2.2/translations/tetzle_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Άνοιγμα Εικόνας</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Εμφάνιση</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Κορνίζα συνόρων</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Σκιές</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Χρώματα</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Φόντος:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Σκιά:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Επισήμανση:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Ελλειπής εικόνα.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Παρακαλώ περιμένετε</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Φόρτωση εικόνας...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Δημιουργία παζλ...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Δημιουργία κομματιών...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Φόρτωση παζλ...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Άγνωστη μορφή δεδομένων</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Άγνωστο στοιχείο &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Σφάλμα κατά την ανάλυση του XML αρχείου.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Φόρτωση κομματιών...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Ανάκτηση κομματιών...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Τοποθέτηση κομματιών...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Επιτυχία</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Επιλογή παιχνιδιού</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Τρέχοντα παιχνίδια</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Καινούργιο παιχνίδι</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Ιδιότητες Εικόνας</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Όνομα:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Κατηγορία:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Επιλογή γλώσσας εφαρμογής:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Σημείωση</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Παρακαλείστε να επανεκκινήσετε την εφαρμογή για να τεθεί σε ισχύ η αλλαγή της γλώσσας.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Προσθήκη Εικόνας</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Αφαίρεση Εικόνας</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Ιδιότητες Εικόνας</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 κομμάτια</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Αντιγραφή εικόνων...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>Αφαίρεση της επιλεγμένης εικόνας;</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Αφαίρεση της επιλεγμένης εικόνας;

Εκεί αποθηκεύονται τα παιχνίδια που χρησιμοποιούν αυτή την εικόνα που θα πρέπει επίσης να αφαιρεθεί.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Χωρίς τίτλο</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Χωρίς τίτλους</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 κομμάτια %2 %3% ολοκληρώθηκαν</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Διαγραφή παιχνιδιού</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Διαγραφή επιλεγμένου παιχνιδιού;</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Επισκόπηση</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Προσθήκη κατηγορίας</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Αφαίρεση Κατηγορίας</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Χωρίς κατηγορία</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Ολες οι εικόνες</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Χωρίς τίτλο %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Ερώτηση</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Αφαίρεση της επιλεγμένης κατηγορίας;</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Συγγνώμη</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Μια κατηγορία με αυτό το όνομα υπάρχει ήδη.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Παιχνίδι</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Ανάκτηση κομματιών</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+Ρ</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Τερματισμός</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Επιλογή...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Εμφάνιση</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Μεγέθυνση</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Μεγέθυνση</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>Καλύτερο ταίριασμα</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Εμφάνιση επ&amp;ισκόπησης</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Καρτέλα</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>Πλήρης οθόνη</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+Φ</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ρυθμίσεις</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Εμφάνιση...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Γλώσσα...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Βοήθεια</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Διαχείριση</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Σχετικά με</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Σχετικά με το &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Διαχείριση</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Κομμάτια πού λύθηκαν:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Πατήστε στην επιλογή αριστερά </translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Μειωμένα Κομμάτια:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Επιλεγμένα Κομμάτια:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Σύρετε Αριστερά</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Περιστροφή κομματιών:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Κάντε δεξί Κλικ για την ανάκτηση ελέγχου + αριστερό κλικ, η πατήστε το πλήκτρο Ρ</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Σύρετε το παζλ:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Κάντε μεσαίο Κλικ, Shift + Αριστερό Κλικ, η χρησιμοποιήστε τα βέλη</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Μεγέθυνση τού παζλ:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Κύλιση η +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Μετακίνηση Δρομέα:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Μετακινήστε το ποντίκι η πατήστε τα πλήκτρα Β,Α,Δ,Σ</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Σχετικά με το Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Παζλ με κομμάτια tetromino</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Πνευματικά δικαιώματα&amp;αντίγραφα; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Κυκλοφορία υπο την άδεια &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>;;%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation>Επιλογή έκδοσης OpenGL.</translation>
    </message>
    <message>
        <source>version</source>
        <translation>έκδοση</translation>
    </message>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
